- add complete support of Issue::close() to workflow, thus passing all arguments to workflow.
- also fixes wrong @phpdoc, as the return value for handleIssueClosed is void, not array
- plus added handleIssueClosed method to workflow/example class, which was missing earlier.

--- ./include/class.workflow.php	2005-07-19 18:16:03.000000000 +0300
+++ /tmp/class.workflow.php	2005-07-20 12:00:32.000000000 +0300
@@ -334,15 +334,19 @@
      * 
      * @param   integer $prj_id The project ID
      * @param   integer $issue_id The ID of the issue.
-     * @return  array An associative array of statuses valid for this issue.
+     * @param   bool $send_notification Whether to send a notification about this action or not
+     * @param   integer $resolution_id The resolution ID
+     * @param   integer $status_id The status ID
+     * @param   string $reason The reason for closing this issue
+     * @return  void
      */
-    function handleIssueClosed($prj_id, $issue_id)
+    function handleIssueClosed($prj_id, $issue_id, $send_notification, $resolution_id, $status_id, $reason)
     {
         if (!Workflow::hasWorkflowIntegration($prj_id)) {
             return;
         }
         $backend =& Workflow::_getBackend($prj_id);
-        return $backend->handleIssueClosed($prj_id, $issue_id);
+        $backend->handleIssueClosed($prj_id, $issue_id, $send_notification, $resolution_id, $status_id, $reason);
     }
     
     
--- ./include/class.issue.php	2005-07-19 18:16:03.000000000 +0300
+++ /tmp/class.issue.php	2005-07-20 12:00:32.000000000 +0300
@@ -1067,7 +1067,7 @@
                 // send notifications for the issue being closed
                 Notification::notify($issue_id, 'closed');
             }
-            Workflow::handleIssueClosed($prj_id, $issue_id);
+            Workflow::handleIssueClosed($prj_id, $issue_id, $send_notification, $resolution_id, $status_id, $reason);
             return 1;
         }
     }
--- ./include/workflow/class.abstract_workflow_backend.php	2005-07-19 18:16:03.000000000 +0300
+++ /tmp/class.abstract_workflow_backend.php	2005-07-20 12:00:32.000000000 +0300
@@ -183,9 +183,13 @@
      * 
      * @param   integer $prj_id The project ID
      * @param   integer $issue_id The ID of the issue.
-     * @return  array An associative array of statuses valid for this issue.
+     * @param   bool $send_notification Whether to send a notification about this action or not
+     * @param   integer $resolution_id The resolution ID
+     * @param   integer $status_id The status ID
+     * @param   string $reason The reason for closing this issue
+     * @return  void
      */
-    function handleIssueClosed($prj_id, $issue_id)
+    function handleIssueClosed($prj_id, $issue_id, $send_notification, $resolution_id, $status_id, $reason)
     {
     }
     
--- ./include/workflow/class.example.php	2005-07-19 18:16:03.000000000 +0300
+++ /tmp/class.example.php	2005-07-20 12:00:32.000000000 +0300
@@ -194,6 +194,23 @@
        // you should perform any logic and remove any statuses you need to here.
        return $statuses;
     }
+
+    /**
+     * Called when issue is closed.
+     * 
+     * @param   integer $prj_id The project ID
+     * @param   integer $issue_id The ID of the issue.
+     * @param   bool $send_notification Whether to send a notification about this action or not
+     * @param   integer $resolution_id The resolution ID
+     * @param   integer $status_id The status ID
+     * @param   string $reason The reason for closing this issue
+     * @return  void
+     */
+    function handleIssueClosed($prj_id, $issue_id, $send_notification, $resolution_id, $status_id, $reason)
+    {
+        echo "Workflow: handleIssueClosed<br />\n";
+    }
+    
     
     
     /**
